==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/tr-TR/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Ön Tanımlı Kitler Hakkında',
    'about_kits_text'                   => 'Ön Tanımlı Kit (sarf malzeme, lisans vb).',
    'checkout'                          => 'Çıkış Tarihi ',
    'create_success'                    => 'Kit başarıyla oluşturuldu.',
    'create'                            => 'Ön Tanımlı Kitler Hakkında',
    'update'                            => 'Ön Tanımlı Kit Düzenle',
    'delete_success'                    => 'Kit başarıyla silindi.',
    'update_success'                    => 'Kit başarıyla güncelleştirildi.',
    'none_models'                       => ':model için çıkış yapılabilecek yeterli uygun malzeme yok, :qty adet gerekmektedir. ',
    'none_licenses'                     => 'Çıkış yapılabilecek sayıda :license lisansı bulunmamaktadır. :qty adet gereklidir. ',
    'none_consumables'                  => 'Yeterli sayıda :consumable olmadığından çıkış yapılamıyor. :qty adet gereklidir. ',
    'none_accessory'                    => 'Çıkış yapılabilecek sayıda :accessory bulunmamaktadır. :qty adet gereklidir. ',
    'append_accessory'                  => 'Ek Aksesuar',
    'update_appended_accessory'         => 'Eklenen Aksesuarı güncelle',
    'append_consumable'                 => 'Sarf Malzemesi Ekle',
    'update_appended_consumable'        => 'Eklenmiş sarf malzemeyi güncelle',
    'append_license'                    => 'Lisans ekle',
    'update_appended_license'           => 'Eklenmiş lisansı güncelle',
    'append_model'                      => 'Model ekle',
    'update_appended_model'             => 'Eklenen modeli güncelle',
    'license_error'                     => 'Lisans zaten eklenmiş',
    'license_added_success'             => 'Lisans sorunsuz eklendi',
    'license_updated'                   => 'Lisans başarıyla güncellendi',
    'license_none'                      => 'Lisans mevcut değil',
    'license_detached'                  => 'Lisans başarıyla kaldırıldı',
    'consumable_added_success'          => 'Sarf malzemesi başarıyla eklendi',
    'consumable_updated'                => 'Sarf malzemesi başarıyla güncellendi',
    'consumable_error'                  => 'Sarf malzemesi zaten kite takılı',
    'consumable_deleted'                => 'Silme işlemi sorunsuz tamamlandı',
    'consumable_none'                   => 'Sarf malzeme mevcut değil',
    'consumable_detached'               => 'Sarf malzemesi başarıyla çıkarıldı',
    'accessory_added_success'           => 'Aksesuar başarıyla eklendi',
    'accessory_updated'                 => 'Aksesuar başarıyla güncellendi',
    'accessory_detached'                => 'Aksesuar başarıyla çıkarıldı',
    'accessory_error'                   => 'Aksesuar zaten kite takılı',
    'accessory_deleted'                 => 'Silme başarılı oldu',
    'accessory_none'                    => 'The accessory does not exist',
    'checkout_success'                  => 'Teslim işlemi başarılı oldu',
    'checkout_error'                    => 'Teslim hatası',
    'kit_none'                          => 'Kit mevcut değil',
    'kit_created'                       => 'Kit başarıyla oluşturuldu',
    'kit_updated'                       => 'Kit başarıyla güncellendi',
    'kit_not_found'                     => 'Kit bulunamadı',
    'kit_deleted'                       => 'Kit başarıyla silindi',
    'kit_model_updated'                 => 'Model başarıyla güncellendi',
    'kit_model_detached'                => 'Model başarıyla ayrıldı',
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/tr-TR/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Ön Tanımlı Kitler Hakkında',
    'about_kits_text'                   => 'Ön Tanımlı Kit (sarf malzeme, lisans vb).',
    'checkout'                          => 'Çıkış Tarihi ',
    'create_success'                    => 'Kit başarıyla oluşturuldu.',
    'create'                            => 'Ön Tanımlı Kitler Hakkında',
    'update'                            => 'Ön Tanımlı Kit Düzenle',
    'delete_success'                    => 'Kit başarıyla silindi.',
    'update_success'                    => 'Kit başarıyla güncelleştirildi.',
    'none_models'                       => ':model için çıkış yapılabilecek yeterli uygun malzeme yok, :qty adet gerekmektedir. ',
    'none_licenses'                     => 'Çıkış yapılabilecek sayıda :license lisansı bulunmamaktadır. :qty adet gereklidir. ',
    'none_consumables'                  => 'Yeterli sayıda :consumable olmadığından çıkış yapılamıyor. :qty adet gereklidir. ',
    'none_accessory'                    => 'Çıkış yapılabilecek sayıda :accessory bulunmamaktadır. :qty adet gereklidir. ',
    'append_accessory'                  => 'Ek Aksesuar',
    'update_appended_accessory'         => 'Eklenen Aksesuarı güncelle',
    'append_consumable'                 => 'Sarf Malzemesi Ekle',
    'update_appended_consumable'        => 'Eklenmiş sarf malzemeyi güncelle',
    'append_license'                    => 'Lisans ekle',
    'update_appended_license'           => 'Eklenmiş lisansı güncelle',
    'append_model'                      => 'Model ekle',
    'update_appended_model'             => 'Eklenen modeli güncelle',
    'license_error'                     => 'Lisans zaten eklenmiş',
    'license_added_success'             => 'Lisans sorunsuz eklendi',
    'license_updated'                   => 'Lisans başarıyla güncellendi',
    'license_none'                      => 'Lisans mevcut değil',
    'license_detached'                  => 'Lisans başarıyla kaldırıldı',
    'consumable_added_success'          => 'Sarf malzemesi başarıyla eklendi',
    'consumable_updated'                => 'Sarf malzemesi başarıyla güncellendi',
    'consumable_error'                  => 'Sarf malzemesi zaten kite takılı',
    'consumable_deleted'                => 'Silme işlemi sorunsuz tamamlandı',
    'consumable_none'                   => 'Sarf malzeme mevcut değil',
    'consumable_detached'               => 'Sarf malzemesi başarıyla çıkarıldı',
    'accessory_added_success'           => 'Aksesuar başarıyla eklendi',
    'accessory_updated'                 => 'Aksesuar başarıyla güncellendi',
    'accessory_detached'                => 'Aksesuar başarıyla çıkarıldı',
    'accessory_error'                   => 'Aksesuar zaten kite takılı',
    'accessory_deleted'                 => 'Silme başarılı oldu',
    'accessory_none'                    => 'Aksesuar mevcut değil',
    'checkout_success'                  => 'Teslim işlemi başarılı oldu',
    'checkout_error'                    => 'Teslim hatası',
    'kit_none'                          => 'Kit mevcut değil',
    'kit_created'                       => 'Kit başarıyla oluşturuldu',
    'kit_updated'                       => 'Kit başarıyla güncellendi',
    'kit_not_found'                     => 'Kit bulunamadı',
    'kit_deleted'                       => 'Kit başarıyla silindi',
    'kit_model_updated'                 => 'Model başarıyla güncellendi',
    'kit_model_detached'                => 'Model başarıyla ayrıldı',
];
